@@ -1,6 +1,5 @@
 import { e2e } from '../';
 import { Flows } from '../flows';
-import { getScenarioContext } from './scenarioContext';
 
 export interface ScenarioArguments {
   describeName: string;
@@ -23,8 +22,11 @@ export const e2eScenario = ({
     if (skipScenario) {
       it.skip(itName, () => scenario());
     } else {
+      before(() => Flows.login(e2e.env('USERNAME'), e2e.env('PASSWORD')));
+
       beforeEach(() => {
-        Flows.login(e2e.env('USERNAME'), e2e.env('PASSWORD'));
+        Cypress.Cookies.preserveOnce('grafana_session');
+
         if (addScenarioDataSource) {
           Flows.addDataSource();
         }
@@ -33,19 +35,13 @@ export const e2eScenario = ({
         }
       });
 
-      afterEach(() => {
-        getScenarioContext().then(({ lastAddedDashboardUid, lastAddedDataSource }: any) => {
-          if (lastAddedDataSource) {
-            Flows.deleteDataSource(lastAddedDataSource);
-          }
-
-          if (lastAddedDashboardUid) {
-            Flows.deleteDashboard(lastAddedDashboardUid);
-          }
-        });
-      });
+      afterEach(() => Flows.revertAllChanges());
+      after(() => e2e().clearCookies());
 
       it(itName, () => scenario());
+
+      // @todo remove when possible: https://github.com/cypress-io/cypress/issues/2831
+      it('temporary', () => {});
     }
   });
 };
